@@ -917,11 +917,16 @@ public class JmsConnection implements AutoCloseable, Connection, TopicConnection
     }
 
     ProviderFuture newProviderFuture() {
-    	return newProviderFuture(null);
+        return newProviderFuture(null);
     }
 
     ProviderFuture newProviderFuture(ProviderSynchronization synchronization) {
-        return provider.newProviderFuture(synchronization);
+        Provider localProvider = provider;
+        if (localProvider != null) {
+            return localProvider.newProviderFuture(synchronization);
+        } else {
+            return null;
+        }
     }
 
     //----- Property setters and getters -------------------------------------//
