@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -20,13 +20,13 @@ import java.util.Enumeration;
 import java.util.NoSuchElementException;
 import java.util.concurrent.atomic.AtomicBoolean;
 
-import javax.jms.IllegalStateException;
-import javax.jms.JMSException;
-import javax.jms.Message;
-import javax.jms.Queue;
-import javax.jms.QueueBrowser;
+import jakarta.jms.IllegalStateException;
+import jakarta.jms.JMSException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.Queue;
+import jakarta.jms.QueueBrowser;
 
-import org.apache.qpid.jms.message.JmsInboundMessageDispatch;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -49,12 +49,12 @@ import org.slf4j.LoggerFactory;
  * A <CODE>QueueBrowser</CODE> can be created from either a <CODE>Session
  * </CODE> or a <CODE>QueueSession</CODE>.
  *
- * @see javax.jms.Session#createBrowser
- * @see javax.jms.QueueSession#createBrowser
- * @see javax.jms.QueueBrowser
- * @see javax.jms.QueueReceiver
+ * @see jakarta.jms.Session#createBrowser
+ * @see jakarta.jms.QueueSession#createBrowser
+ * @see jakarta.jms.QueueBrowser
+ * @see jakarta.jms.QueueReceiver
  */
-public class JmsQueueBrowser implements QueueBrowser, Enumeration<Message> {
+public class JmsQueueBrowser implements AutoCloseable, QueueBrowser, Enumeration<Message> {
 
     protected static final Logger LOG = LoggerFactory.getLogger(JmsQueueBrowser.class);
 
@@ -62,20 +62,22 @@ public class JmsQueueBrowser implements QueueBrowser, Enumeration<Message> {
     private final JmsDestination destination;
     private final String selector;
 
-    private JmsMessageConsumer consumer;
-    private final AtomicBoolean browseDone = new AtomicBoolean(false);
+    private volatile JmsMessageConsumer consumer;
 
     private Message next;
     private final AtomicBoolean closed = new AtomicBoolean();
-    private final Object semaphore = new Object();
 
     /**
      * Constructor for an JmsQueueBrowser - used internally
      *
      * @param session
+     *      The Session that owns this instance.
      * @param destination
+     *      The Destination that will be browsed.
      * @param selector
-     * @throws javax.jms.JMSException
+     *      The selector string used to filter the browsed message.
+     *
+     * @throws jakarta.jms.JMSException if an error occurs while creating this instance.
      */
     protected JmsQueueBrowser(JmsSession session, JmsDestination destination, String selector) throws JMSException {
         this.session = session;
@@ -83,40 +85,21 @@ public class JmsQueueBrowser implements QueueBrowser, Enumeration<Message> {
         this.selector = selector;
     }
 
-    private void destroyConsumer() {
-        if (consumer == null) {
-            return;
-        }
-        try {
-            consumer.close();
-            consumer = null;
-        } catch (JMSException e) {
-            e.printStackTrace();
-        }
-    }
-
     /**
      * Gets an enumeration for browsing the current queue messages in the order they would be
      * received.
      *
      * @return an enumeration for browsing the messages
-     * @throws javax.jms.JMSException
+     * @throws jakarta.jms.JMSException
      *         if the JMS provider fails to get the enumeration for this browser due to some
      *         internal error.
      */
     @Override
     public Enumeration<Message> getEnumeration() throws JMSException {
         checkClosed();
-        if (consumer == null) {
-            consumer = createConsumer();
-        }
-        return this;
-    }
+        createConsumer();
 
-    private void checkClosed() throws IllegalStateException {
-        if (closed.get()) {
-            throw new IllegalStateException("The Consumer is closed");
-        }
+        return this;
     }
 
     /**
@@ -125,10 +108,9 @@ public class JmsQueueBrowser implements QueueBrowser, Enumeration<Message> {
     @Override
     public boolean hasMoreElements() {
         while (true) {
-            synchronized (this) {
-                if (consumer == null) {
-                    return false;
-                }
+            MessageConsumer consumer = this.consumer;
+            if (consumer == null) {
+                return false;
             }
 
             if (next == null) {
@@ -140,17 +122,13 @@ public class JmsQueueBrowser implements QueueBrowser, Enumeration<Message> {
 
                 if (next != null) {
                     return true;
+                } else {
+                    destroyConsumer();
+                    return false;
                 }
             } else {
                 return true;
             }
-
-            if (browseDone.get() || !session.isStarted()) {
-                destroyConsumer();
-                return false;
-            }
-
-            waitForMessage();
         }
     }
 
@@ -161,11 +139,6 @@ public class JmsQueueBrowser implements QueueBrowser, Enumeration<Message> {
      */
     @Override
     public Message nextElement() {
-        synchronized (this) {
-            if (consumer == null) {
-                return null;
-            }
-        }
 
         if (hasMoreElements()) {
             Message message = next;
@@ -173,7 +146,7 @@ public class JmsQueueBrowser implements QueueBrowser, Enumeration<Message> {
             return message;
         }
 
-        if (browseDone.get() || !session.isStarted()) {
+        if (!session.isStarted()) {
             destroyConsumer();
             return null;
         }
@@ -184,7 +157,6 @@ public class JmsQueueBrowser implements QueueBrowser, Enumeration<Message> {
     @Override
     public void close() throws JMSException {
         if (closed.compareAndSet(false, true)) {
-            browseDone.set(true);
             destroyConsumer();
         }
     }
@@ -193,11 +165,10 @@ public class JmsQueueBrowser implements QueueBrowser, Enumeration<Message> {
      * Gets the queue associated with this queue browser.
      *
      * @return the queue
-     * @throws javax.jms.JMSException
+     * @throws jakarta.jms.JMSException
      *         if the JMS provider fails to get the queue associated with this browser due to
      *         some internal error.
      */
-
     @Override
     public Queue getQueue() throws JMSException {
         return (Queue) destination;
@@ -208,51 +179,45 @@ public class JmsQueueBrowser implements QueueBrowser, Enumeration<Message> {
         return selector;
     }
 
-    /**
-     * Wait on a semaphore for a fixed amount of time for a message to come in.
-     */
-    protected void waitForMessage() {
-        try {
-            synchronized (semaphore) {
-                semaphore.wait(2000);
-            }
-        } catch (InterruptedException e) {
-            Thread.currentThread().interrupt();
-        }
-    }
-
-    protected void notifyMessageAvailable() {
-        synchronized (semaphore) {
-            semaphore.notifyAll();
-        }
-    }
-
     @Override
     public String toString() {
         JmsMessageConsumer consumer = this.consumer;
         return "JmsQueueBrowser { value=" + (consumer != null ? consumer.getConsumerId() : "null") + " }";
     }
 
-    private JmsMessageConsumer createConsumer() throws JMSException {
-        browseDone.set(false);
-        JmsMessageConsumer rc = new JmsMessageConsumer(session.getNextConsumerId(), session, destination, selector, false) {
+    private void checkClosed() throws IllegalStateException {
+        if (closed.get()) {
+            throw new IllegalStateException("The Consumer is closed");
+        }
+    }
 
-            @Override
-            public boolean isBrowser() {
-                return true;
-            }
-
-            @Override
-            public void onInboundMessage(JmsInboundMessageDispatch envelope) {
-                if (envelope.getMessage() == null) {
-                    browseDone.set(true);
-                } else {
-                    super.onInboundMessage(envelope);
+    private synchronized void destroyConsumer() {
+        synchronized (this) {
+            try {
+                if (consumer != null) {
+                    consumer.close();
                 }
-                notifyMessageAvailable();
+            } catch (JMSException e) {
+                LOG.trace("Error closing down internal consumer: ", e);
+            } finally {
+                consumer = null;
             }
-        };
-        rc.init();
-        return rc;
+        }
+    }
+
+    private synchronized void createConsumer() throws JMSException {
+        if (consumer == null) {
+            JmsMessageConsumer result = new JmsMessageConsumer(session.getNextConsumerId(), session, destination, selector, false) {
+
+                @Override
+                public boolean isBrowser() {
+                    return true;
+                }
+            };
+            result.init();
+
+            // Assign only after fully created and initialized.
+            consumer = result;
+        }
     }
 }
