@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -16,8 +16,8 @@
  */
 package org.apache.qpid.jms;
 
-import javax.jms.JMSException;
-import javax.jms.TemporaryQueue;
+import jakarta.jms.JMSException;
+import jakarta.jms.TemporaryQueue;
 
 /**
  * Temporary Queue Object
@@ -33,7 +33,7 @@ public class JmsTemporaryQueue extends JmsTemporaryDestination implements Tempor
     }
 
     /**
-     * @see javax.jms.TemporaryQueue#delete()
+     * @see jakarta.jms.TemporaryQueue#delete()
      */
     @Override
     public void delete() throws JMSException {
@@ -42,10 +42,10 @@ public class JmsTemporaryQueue extends JmsTemporaryDestination implements Tempor
 
     /**
      * @return name
-     * @see javax.jms.Queue#getQueueName()
+     * @see jakarta.jms.Queue#getQueueName()
      */
     @Override
     public String getQueueName() {
-        return getName();
+        return getAddress();
     }
 }
