@@ -20,9 +20,9 @@ import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
-import javax.jms.JMSException;
-import javax.jms.JMSSecurityException;
-import javax.jms.TopicConnection;
+import jakarta.jms.JMSException;
+import jakarta.jms.JMSSecurityException;
+import jakarta.jms.TopicConnection;
 
 import org.apache.qpid.jms.support.AmqpTestSupport;
 import org.junit.jupiter.api.Test;
