@@ -53,10 +53,9 @@ import org.apache.activemq.security.SimpleAuthenticationPlugin;
 import org.apache.activemq.security.TempDestinationAuthorizationEntry;
 import org.apache.activemq.store.kahadb.KahaDBStore;
 import org.apache.activemq.util.JMXSupport;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.rules.TestName;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestInfo;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -69,8 +68,6 @@ public class QpidJmsTestSupport {
 
     public static final String KAHADB_DIRECTORY = "target/activemq-data";
 
-    @Rule public TestName name = new TestName();
-
     protected static final Logger LOG = LoggerFactory.getLogger(QpidJmsTestSupport.class);
     protected BrokerService brokerService;
     protected final List<BrokerService> brokers = new ArrayList<BrokerService>();
@@ -78,16 +75,18 @@ public class QpidJmsTestSupport {
     protected int numberOfMessages;
     protected Connection connection;
     protected javax.jms.Connection jmsConnection;
+    protected String testMethodName;
 
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    public void setUp(TestInfo testInfo) throws Exception {
+        this.testMethodName = testInfo.getTestMethod().get().getName();
         LOG.info("========== setUp " + getTestName() + " ==========");
         exceptions.clear();
         startPrimaryBroker();
         this.numberOfMessages = 2000;
     }
 
-    @After
+    @AfterEach
     public void tearDown() throws Exception {
         LOG.info("========== tearDown " + getTestName() + " ==========");
         Exception firstError = null;
@@ -132,7 +131,7 @@ public class QpidJmsTestSupport {
     }
 
     public String getDestinationName() {
-        return name.getMethodName();
+        return testMethodName;
     }
 
     public URI getBrokerActiveMQClientConnectionURI() {
@@ -407,7 +406,7 @@ public class QpidJmsTestSupport {
     protected void sendToAmqQueue(int count) throws Exception {
         javax.jms.Connection activemqConnection = createActiveMQConnection();
         javax.jms.Session amqSession = activemqConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        javax.jms.Queue amqTestQueue = amqSession.createQueue(name.getMethodName());
+        javax.jms.Queue amqTestQueue = amqSession.createQueue(testMethodName);
         sendMessages(activemqConnection, amqTestQueue, count);
         activemqConnection.close();
     }
@@ -415,7 +414,7 @@ public class QpidJmsTestSupport {
     protected void sendToAmqTopic(int count) throws Exception {
         javax.jms.Connection activemqConnection = createActiveMQConnection();
         javax.jms.Session amqSession = activemqConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        javax.jms.Topic amqTestTopic = amqSession.createTopic(name.getMethodName());
+        javax.jms.Topic amqTestTopic = amqSession.createTopic(testMethodName);
         sendMessages(activemqConnection, amqTestTopic, count);
         activemqConnection.close();
     }
@@ -504,6 +503,6 @@ public class QpidJmsTestSupport {
     }
 
     protected String getTestName() {
-        return getClass().getSimpleName() + "." + name.getMethodName();
+        return getClass().getSimpleName() + "." + testMethodName;
     }
 }
